@@ -1,5 +1,5 @@
 package Net::Easypost;
-$Net::Easypost::VERSION = '0.15';
+$Net::Easypost::VERSION = '0.16';
 use Data::Dumper;
 use Carp qw(croak);
 use Hash::Merge::Simple qw(merge);
@@ -16,7 +16,7 @@ use Net::Easypost::Shipment;
 
 
 
-has requestor => (
+has 'requester' => (
     is      => 'ro',
     lazy    => 1,
     default => sub { return Net::Easypost::Request->new }
@@ -39,7 +39,7 @@ sub verify_address {
 
 
 sub get_rates {
-    my $self = shift;
+    my $self = shift; # shift is important here
 
     my $params;
     if ( scalar @_ == 1 ) {
@@ -75,7 +75,10 @@ sub buy_label {
 sub get_label {
     my ($self, $label_filename) = @_;
 
-    my $resp = $self->requestor->post('/postage/get', { label_file_name => $label_filename } );
+    my $resp = $self->requester->post(
+        '/postage/get', 
+        { label_file_name => $label_filename } 
+    );
 
     return Net::Easypost::Label->new(
         rate          => Net::Easypost::Rate->new( $resp->{rate} ),
@@ -88,9 +91,11 @@ sub get_label {
 
 
 sub list_labels {
-    my $self = shift;
+    my ($self) = @_;
 
-    my $resp = $self->requestor->get( $self->requestor->_build_url('/postage/list') );
+    my $resp = $self->requester->get( 
+        $self->requester->_build_url('/postage/list') 
+    );
 
     return $resp->{postages};
 }
@@ -110,7 +115,7 @@ Net::Easypost - Perl client for the Easypost web service
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -169,11 +174,11 @@ recommend using L<Try::Tiny> in your implementation.
 API key:
 
 You must have your API key stored in an environment variable named 
-EASYPOST_API_KEY (recommended)
+EASYPOST_API_KEY
 
 =head1 ATTRIBUTES
 
-=head2 requestor
+=head2 requester
 
 HTTP client to POST and GET
 
