@@ -1,68 +1,59 @@
 package Net::Easypost::Label;
-$Net::Easypost::Label::VERSION = '0.15';
-use Carp qw(croak);
-use IO::Handle;
+$Net::Easypost::Label::VERSION = '0.16';
 use Moo;
-use Net::Easypost::Request;
-
 with qw(Net::Easypost::Resource);
 
+use Carp qw(croak);
+use Net::Easypost::Request;
 
-has tracking_code => (
+has 'tracking_code' => (
     is       => 'ro',
     required => 1
 );
 
-
-has filename => (
+has 'filename' => (
     is       => 'ro',
-    required => '1',
+    required => 1,
 );
 
-
-has filetype => (
+has 'filetype' => (
     is      => 'ro',
     lazy    => 1,
-    default => sub { 'image/png' }
+    default => 'image/png',
 );
 
-
-
-has url => (
+has 'url' => (
    is        => 'ro',
    predicate => 1,
    required  => 1,
 );
 
-
-has rate => (
+has 'rate' => (
    is  => 'ro',
 );
 
-
-
-
-has image => (
+has 'image' => (
     is        => 'ro',
     lazy      => 1,
     predicate => 1,
     default   => sub {
-        my $self = shift;
+        my ($self) = @_;
 
-        croak "can't retrieve image for " . $self->filename . " without a url"
+        croak "Cannot retrieve image for " . $self->filename . " without URL"
             unless $self->has_url;
 
         return $self->requester->get($self->url)->content->asset->slurp;
     }
 );
 
+sub _build_operation { '' }
 sub _build_role { 'label' }
-sub _build_fieldnames { [qw(tracking_code url filetype filename)] }
-
-
+sub _build_fieldnames { 
+    return [qw/tracking_code url filetype filename/];
+}
 
 sub save {
-    my $self = shift;
+    my ($self) = @_;
 
     $self->image
         unless $self->has_image;
@@ -71,9 +62,10 @@ sub save {
         or croak "Couldn't save " . $self->filename . ": $!";
 
     print {$fh} $self->image;
-    $fh->close;
-}
+    close($fh);
 
+    return 1;
+}
 
 sub clone {
    my $self = shift;
@@ -85,15 +77,13 @@ sub clone {
    );
 }
 
-
 sub serialize {
-   my $self = shift;
+   my ($self) = @_;
 
-   # want a hashref of e.g., role[field1] => foo from all defined attributes
    return {
-      map { $self->role . "[$_]" => $self->$_ }
-         grep { defined $self->$_ }
-            @{ $self->fieldnames }
+      map  { $self->role . "[$_]" => $self->$_ }
+      grep { defined $self->$_ }
+         @{ $self->fieldnames }
    };
 }
 
@@ -111,59 +101,75 @@ Net::Easypost::Label
 
 =head1 VERSION
 
-version 0.15
+version 0.16
+
+=head1 SYNOPSIS
+
+Net::Easypost::Label->new
+
+=head1 NAME 
+
+Net::Easypost::Label
 
 =head1 ATTRIBUTES
 
-=head2 tracking_code
+=over 4 
+
+=item tracking_code
 
 The carrier generated tracking code for this label.
 
-=head2 filename
+=item filename
 
 The filename the Easypost API used to create the label file. (Also used
 for local storage.)
 
-=head2 filetype
+=item filetype
 
 The file type for the image data. Defaults to 'image/png'
 
-=head2 url
+=item url
 
 The URL from which to download the label image.
 
-=head2 rate
+=item rate
 
 The chosen rate for this Label
 
-=head2 image
+has rate => (
+   is  => 'ro',
+);
+
+=item image
 
 This is the label image data.  It lazily downloads this information if a
 URL is defined. It currently uses a L<Net::Easypost::Request> role to
 get the data from the Easypost service.
 
+=back
+
 =head1 METHODS
 
-=head2 has_url
+=over 4 
 
-This is a predicate which tells the caller if a URL is defined in the object.
+=item _build_fieldnames
 
-=head2 has_image
+=item _build_role
 
-Tells the caller if an image has been downloaded.
-
-=head2 save
+=item save
 
 Store the label image locally using the filename in the object. This will typically be
 in the current working directory of the caller.
 
-=head2 clone
+=item clone 
 
 returns a new Net::Easypost::Label object that is a deep-copy of this object
 
-=head2 serialize
+=item serialize
 
-serialized form for Label objects
+serialized format for Label objects
+
+=back
 
 =head1 AUTHOR
 
