@@ -1,54 +1,26 @@
 package Net::Easypost::Parcel;
-$Net::Easypost::Parcel::VERSION = '0.15';
+$Net::Easypost::Parcel::VERSION = '0.16';
 use Moo;
-
 with qw(Net::Easypost::PostOnBuild);
 with qw(Net::Easypost::Resource);
 
-# ABSTRACT: An object to represent an Easypost parcel
-
-
-has length => (
+has [qw/length width height weight predefined_package/] => (
     is => 'rw',
 );
 
-
-has width => (
-    is => 'rw',
-);
-
-
-has height => (
-    is => 'rw',
-);
-
-
-has weight => (
-    is => 'rw',
-);
-
-
-has predefined_package => (
-    is => 'rw',
-);
-
-
-sub _build_fieldnames { [qw(length width height weight predefined_package)] }
-
-
-sub _build_role { 'parcel' }
-
-
+sub _build_fieldnames { 
+    return [qw/length width height weight predefined_package/];
+}
+sub _build_role      { 'parcel'   }
 sub _build_operation { '/parcels' }
 
-
 sub clone {
-    my $self = shift;
+    my ($self) = @_;
 
     return Net::Easypost::Parcel->new(
-        map { $_ => $self->$_ }
-            grep { defined $self->$_ }
-                'id', $self->fieldnames
+        map  { $_ => $self->$_ }
+        grep { defined $self->$_ }
+           'id', @{ $self->fieldnames }
     );
 }
 
@@ -62,52 +34,68 @@ __END__
 
 =head1 NAME
 
-Net::Easypost::Parcel - An object to represent an Easypost parcel
+Net::Easypost::Parcel
 
 =head1 VERSION
 
-version 0.15
+version 0.16
+
+=head1 SYNOPSIS
+
+Net::Easypost::Parcel->new
+
+=head1 NAME 
+
+Net::Easypost::Parcel
 
 =head1 ATTRIBUTES
 
-=head2 length
+=over 4 
+
+=item length
 
 The length of the parcel in inches.
 
-=head2 width
+=item width
 
 The width of the parcel in inches.
 
-=head2 height
+=item height
 
 The height of the parcel in inches.
 
-=head2 weight
+=item weight
 
 The weight of the parcel in ounces. (There are 16 ounces in a U.S. pound.)
 
-=head2 predefined_package
+=item predefined_package
 
 A carrier specific flat-rate package name. See L<https://www.easypost.com/docs/api/#predefined-packages> for these.
 
-=head1 METHODS
+=back
 
-=head2 _build_fieldnames
+=head1 METHODS 
+
+=over 4 
+
+=item _build_fieldnames 
 
 Attributes that make up an Parcel, from L<Net::Easypost::Resource>
 
-=head2 _build_role
+=item _build_role
 
 Prefix to data when POSTing to the Easypost API about Parcel objects
 
-=head2 _build_operation
+=item _build_operation
 
-Base API endpoint for operations on Address objects
+Base API endpoint for operations on Parcel objects
 
-=head2 clone
+=item clone 
 
 returns a new Net::Easypost::Parcel object that is a deep-copy of this object
 
+=back
+
 =head1 AUTHOR
 
 Mark Allen <mrallen1@yahoo.com>, Hunter McMillen <mcmillhj@gmail.com>
