@@ -1,49 +1,38 @@
 package Net::Easypost::Rate;
-$Net::Easypost::Rate::VERSION = '0.15';
+$Net::Easypost::Rate::VERSION = '0.16';
 use Moo;
-
 with qw(Net::Easypost::Resource);
 
-
-has carrier => (
-  is      => 'ro',
-  lazy    => 1,
-  default => sub { 'USPS' },
+has 'carrier' => (
+    is      => 'ro',
+    default => 'USPS',
 );
 
-
-has service => (
-  is => 'ro',
+has [qw/service rate shipment_id/] => (
+    is => 'ro',
 );
 
-
-has rate => (
-  is => 'ro',
-);
-
-
-has shipment_id => (
-  is => 'ro',
-);
-
-sub _build_fieldnames { [qw(carrier service rate shipment_id)] }
-sub _build_role { 'rate' }
-
+sub _build_fieldnames { 
+    return [qw(carrier service rate shipment_id)];
+}
+sub _build_role      { 'rate' }
+sub _build_operation { ''     }
 
 sub serialize {
-   my $self = shift;
+   my ($self) = @_;
 
-   return { 'rate[id]' => $self->id };
+   return { 
+       'rate[id]' => $self->id 
+   };
 }
 
-
 sub clone {
-   my $self = shift;
+   my ($self) = @_;
 
    return Net::Easypost::Rate->new(
-      map { $_ => $self->$_ }
-         grep { defined $self->$_ }
-            'id', @{ $self->fieldnames }
+       map  { $_ => $self->$_ }
+       grep { defined $self->$_ }
+           'id', @{ $self->fieldnames }
    );
 }
 
@@ -61,37 +50,57 @@ Net::Easypost::Rate
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
-=head1 ATTRIBUTES
+=head1 NAME 
 
-=head2 carrier
+Net::Easypost::Rate
+
+=head1 SYNOPSIS 
+
+Net::Easypost::Rate->new
+
+=head1 ATTRIBUTES 
+
+=over 4 
+
+=item carrier
 
 The shipping carrier. At the current time, the United States Postal Service (USPS) is the only
 supported carrier.
 
-=head2 service
+=item service
 
 The shipping service name. For example, for the USPS, these include 'Priority', 'Express',
 'Media Mail' and others.
 
-=head2 rate
+=item rate
 
 The price in US dollars to ship using the associated carrier and service.
 
-=head2 shipment_id
+=item shipment_id
 
 ID of the shipment that this Rate object relates to
 
-=head1 METHODS
+=back
 
-=head2 serialize
+=head1 METHODS 
+
+=over 4 
+
+=item _build_fieldnames 
+
+=item _build_role 
+
+=item clone 
+
+returns a new Rate object that is a deep-copy of this Rate object
+
+=item serialize
 
 serialized form of Rate objects
 
-=head2 clone
-
-returns a new Rate object that is a deep-copy of this Rate object
+=back
 
 =head1 AUTHOR
 
