@@ -1,38 +1,33 @@
 package Net::Easypost::Resource;
-$Net::Easypost::Resource::VERSION = '0.15';
-use Carp qw(croak);
+$Net::Easypost::Resource::VERSION = '0.16';
 use Moo::Role;
+
+use Carp qw(croak);
 use Net::Easypost::Request;
 
-# all Net::Easypost::Resource objects must implementat clone and serialize
+# all Net::Easypost::Resource objects must implement clone and serialize
 requires qw(serialize clone);
 
-
 has id => (
    is => 'rwp',
 );
 
-
-has operation => (
-   is      => 'ro',
-   lazy    => 1,
-   builder => 1,
-);
-
-
-has role => (
+has 'operation' => (
    is      => 'ro',
    builder => 1,
 );
 
-
-has fieldnames => (
+has 'role' => (
    is      => 'ro',
    builder => 1,
 );
 
+has 'fieldnames' => (
+   is      => 'ro',
+   builder => 1,
+);
 
-has requester => (
+has 'requester' => (
    is      => 'ro',
    default => sub { Net::Easypost::Request->new },
 );
@@ -51,30 +46,40 @@ Net::Easypost::Resource
 
 =head1 VERSION
 
-version 0.15
+version 0.16
+
+=head1 SYNOPSIS
+
+=head1 NAME 
+
+Net::Easypost::Resource
 
 =head1 ATTRIBUTES
 
-=head2 id
+=over 4 
+
+=item id
 
 A unique field that represent this Object to Easypost
 
-=head2 endpoint
+=item endpoint
 
 base API operation endpoint for this Object
 
-=head2 role
+=item role
 
 Role of this object: address, shipment, parcel, etc...
 
-=head2 fieldnames
+=item fieldnames
 
 attributes of this Object in the Easypost API
 
-=head2 requester
+=item requester
 
 HTTP client to make GET & POST requests
 
+=back
+
 =head1 AUTHOR
 
 Mark Allen <mrallen1@yahoo.com>, Hunter McMillen <mcmillhj@gmail.com>
