@@ -1,71 +1,54 @@
 package Net::Easypost::Shipment;
-$Net::Easypost::Shipment::VERSION = '0.15';
-use Carp qw(croak);
-use Data::Dumper;
+$Net::Easypost::Shipment::VERSION = '0.16';
 use Moo;
-use Types::Standard qw(ArrayRef HashRef InstanceOf Str);
+with qw/Net::Easypost::PostOnBuild/;
+with qw/Net::Easypost::Resource/;
 
-with qw(Net::Easypost::PostOnBuild);
-with qw(Net::Easypost::Resource);
+use Carp qw/croak/;
+use Types::Standard qw/ArrayRef HashRef InstanceOf Str/;
 
-
-has to_address => (
+has [qw/from_address to_address/] => (
    is       => 'ro',
    isa      => InstanceOf['Net::Easypost::Address'],
    required => 1,
 );
 
-
-has from_address => (
-   is       => 'ro',
-   isa      => InstanceOf['Net::Easypost::Address'],
-   required => 1,
-);
-
-
-has parcel => (
+has 'parcel' => (
    is       => 'rw',
    isa      => InstanceOf['Net::Easypost::Parcel'],
    required => 1,
 );
 
-
-has customs_info => (
+has 'customs_info' => (
    is  => 'rw',
    isa => InstanceOf['Net::Easypost::CustomsInfo'],
 );
 
-
-has scan_form => (
+has 'scan_form' => (
    is  => 'rw',
    isa => InstanceOf['Net::Easypost::ScanForm'],
 );
 
-
-has rates => (
+has 'rates' => (
    is  => 'rwp',
-   isa => ArrayRef[ InstanceOf['Net::Easypost::Rate'] ],
+   isa => ArrayRef[InstanceOf['Net::Easypost::Rate']],
 );
 
-
-has options => (
+has 'options' => (
    is  => 'rw',
    isa => HashRef[Str],
 );
 
+sub _build_fieldnames { 
+    return [qw/to_address from_address parcel customs_info scan_form rates options/];
+}
 
-sub _build_fieldnames { [qw(to_address from_address parcel customs_info scan_form rates options)] }
-
-
-sub _build_role { 'shipment' }
-
-
+sub _build_role      { 'shipment'   }
 sub _build_operation { '/shipments' }
 
-
 sub BUILD {}
 after BUILD => sub {
-   my $self = shift;
+   my ($self) = @_;
 
    my $resp = $self->requester->post(
       $self->operation,
@@ -86,25 +69,24 @@ after BUILD => sub {
    );
 };
 
-
 sub serialize {
-   my $self = shift;
+   my ($self) = @_;
 
    # want a hashref of e.g., shipment[to_address][id] => foo from all defined attributes
    return {
-      map { $self->role . "[$_][id]" => $self->$_->id }
-         grep { defined $self->$_ }
-            qw(to_address from_address parcel)
+       map { $self->role . "[$_][id]" => $self->$_->id }
+       grep { defined $self->$_ }
+          qw(to_address from_address parcel)
    };
 }
 
 sub clone {
-   my $self = shift;
+   my ($self) = @_;
 
    return Net::Easypost::Shipment->new(
-      map { $_ => $self->$_ }
-         grep { defined $self->$_ }
-            'id', $self->fieldnames
+       map  { $_ => $self->$_ }
+       grep { defined $self->$_ }
+          'id', @{ $self->fieldnames }
    );
 }
 
@@ -114,19 +96,19 @@ sub buy {
    my $rate; 
    if ( exists $options{rate} && $options{rate} eq 'lowest' ) {
       ($rate) = 
-         sort { $a->{rate} <=> $b->{rate} } @{$self->rates};
+         sort { $a->{rate} <=> $b->{rate} } @{ $self->rates };
    } 
    elsif ( exists $options{service_type} ) {
       ($rate) =
-         grep { $options{service_type} eq $_->service } @{$self->rates};
+         grep { $options{service_type} eq $_->service } @{ $self->rates };
    }
    else {
       croak "Missing 'service' or 'rate' from options hash";
    }
 
-   if ( !$rate ) {
+   unless ( $rate ) {
       my $msg = "Allowed services and rates for this shipment are:\n";
-      foreach my $rate ( @{$self->rates} ) {
+      foreach my $rate ( @{ $self->rates } ) {
          $msg .= sprintf("\t%-15s: %4.2f\n", $rate->service, $rate->rate);
       }
 
@@ -166,61 +148,83 @@ Net::Easypost::Shipment
 
 =head1 VERSION
 
-version 0.15
+version 0.16
+
+=head1 SYNOPSIS
+
+Net::Easypost::Shipment->new
+
+=head1 NAME 
+
+Net::Easypost::Shipment
 
 =head1 ATTRIBUTES
 
-=head2 to_address
+=over 4 
+
+=item to_address
 
 Address this Shipment is going to
 
-=head2 from_address
+=item from_address
 
 Address this Shipment is coming from
 
-=head2 parcel
+=item parcel
 
 Parcel that is being shipped
 
-=head2 customs_info
+=item customs_info
 
 Customs information about this Shipment, optional (only for international shipments)
 
-=head2 scan_form
+=item scan_form
 
 USPS Tracking information, optional
 
-=head2 rates
+=item rates
 
 Array of Net::Easypost::Rate objects
 
-=head2 options
+=item options
 
 Array of shipping options, may not be supported by all carriers
 
+=back
+
 =head1 METHODS
 
-=head2 _build_fieldnames
+=over 4 
+
+=item _build_fieldnames
 
 Attributes that make up an Address, from L<Net::Easypost::Resource>
 
-=head2 _build_role
+=item _build_role
 
 Prefix to data when POSTing to the Easypost API about Address objects
 
-=head2 _build_operation
+=item _build_operation
 
 Base API endpoint for operations on Address objects
 
-=head2 BUILD
+=item BUILD
 
 Constructor for a Shipment object, overrides the base BUILD method in L<Net::Easypost::PostOnBuild>
 
-=head2 serialize
+=item clone
+
+return a deep-copy of this object
+
+=item serialize
 
 Format this object into a form suitable for use with the Easypost service.
 Overrides base implementation in L<Net::Easypost::PostOnBuild>
 
+=item buy
+
+=back
+
 =head1 AUTHOR
 
 Mark Allen <mrallen1@yahoo.com>, Hunter McMillen <mcmillhj@gmail.com>
